==> inti_0.5.4.tar.gz: inti/inst/yupana/www/msgs.R <==
# -------------------------------------------------------------------------
# yupana ------------------------------------------------------------------
# -------------------------------------------------------------------------
#> open https://flavjack.github.io/inti/
#> open https://flavjack.shinyapps.io/yupanapro/
#> author .: Flavio Lozano-Isla (lozanoisla.com)
#> date .: 2021-04-29
# -------------------------------------------------------------------------

suppressPackageStartupMessages({library(inti)})

# -------------------------------------------------------------------------
# message -----------------------------------------------------------------
# -------------------------------------------------------------------------

head <- colortext(
  "
# -------------------------------------------------------------------------
# ReadMe ------------------------------------------------------------------
# -------------------------------------------------------------------------
  "
)

end <- colortext(
  "
# -------------------------------------------------------------------------
# Yupana ------------------------------------------------------------------
# -------------------------------------------------------------------------
  "
)


message(
  head
  , "\n"
  , colortext("- ")
  , colortext("If is the first time running the app consider install the dependencies:")
  , "\n\n"
  , colortext("> ")
  , colortext("inti::yupana(dependencies = TRUE)", "green")
  , "\n\n"
  , colortext("- ")
  , colortext("More info: ")
  , colortext("https://inkaverse.com/articles/apps", "blue")
  , "\n"
  , end
)

remove(head, end)

==> inti_0.6.8.tar.gz: inti/inst/yupana/www/msgs.R <==
# -------------------------------------------------------------------------
# yupana ------------------------------------------------------------------
# -------------------------------------------------------------------------
#> open https://flavjack.github.io/inti/
#> open https://flavjack.shinyapps.io/yupanapro/
#> author .: Flavio Lozano-Isla (lozanoisla.com)
#> date .: 2021-04-29
# -------------------------------------------------------------------------

suppressPackageStartupMessages({library(inti)})

# -------------------------------------------------------------------------
# message -----------------------------------------------------------------
# -------------------------------------------------------------------------

head <- colortext(
  "
# -------------------------------------------------------------------------
# ReadMe ------------------------------------------------------------------
# -------------------------------------------------------------------------
  "
  , "brown"
)

end <- colortext(
  "
# -------------------------------------------------------------------------
# Yupana ------------------------------------------------------------------
# -------------------------------------------------------------------------
  "
  , "brown"
)


message(
  head
  , "\n"
  , colortext("- ")
  , colortext("More info: ")
  , colortext("\n\n")
  , colortext("> https://inkaverse.com/", "blue")
  , "\n\n"
  , colortext("- ")
  , colortext("Citation: ")
  , colortext("\n\n")
  , colortext("> https://inkaverse.com/authors.html#citation", "green")
  , "\n"
  , end
)

remove(head, end)
